@@ -179,7 +179,7 @@ class LoadMaster(HttpClient):
         # Can't use the HttpClient methods for this as the
         # endpoint is different when attempting to enable the API.
         url = ("https://{user}:{pw}@{ip}"
-               "/progs/doconfig/enableapi/set/yes/").format(user=self.username,
+               "/progs/doconfig/enableapi/set/yes").format(user=self.username,
                                                             pw=self.password,
                                                             ip=self.ip_address)
         try:
